// FlashTestLed.c
// 
// functions and main
///////////////////////////////////////////////////////////////////////////////


/*-------------------------------------------------------------------------
   Written by: 
   Peter Seng (2004)
   
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any
   later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

   In other words, you are welcome to use, share and improve this program.
   You are forbidden to forbid anyone else to use, share and improve
   what you give them.   Help stamp out software-hoarding!
-------------------------------------------------------------------------*/


// used MCU
// Philips P80C32 SBAA ( 256 Byte RAM,  0KByte EPROM )
// 3 Timer, UART, @ 11.0592 MHz


// compiler commandline
// sdcc flashtestled.c 


// Port-map of the MCU
// P0_0 -> AD0                                                   
// P0_1 -> AD1                                                  
// P0_2 -> AD2                                                
// P0_3 -> AD3
// P0_4 -> AD4
// P0_5 -> AD5                                                
// P0_6 -> AD6                                                
// P0_7 -> AD7                                                 
// P1_0 -> unused                                                   
// P1_1 -> unused                                                   
// P1_2 -> unused                                                   
// P1_3 -> unused                                                   
// P1_4 -> unused                                                   
// P1_5 -> unused                                                   
// P1_6 -> unused                                                   
// P1_7 -> unused                                                   
// P2_0 -> A8                                                
// P2_1 -> A9                                                 
// P2_2 -> A10                                                 
// P2_3 -> A11                                                
// P2_4 -> A12                                                
// P2_5 -> A13                                                
// P2_6 -> A14                                                
// P2_7 -> A15                                              
// P3_0 -> [RXD] unused                                            
// P3_1 -> [TXD] unused                                            
// P3_2 -> [INT0] unused                                            
// P3_3 -> [INT1] unused                                            
// P3_4 -> [T0] unused                                            
// P3_5 -> [T1] unused                                            
// P3_6 -> [WR] TestLed                                           
// P3_7 -> [RD] unused                                            


// includes
#include "include/8052.h" // Definitions of 8052 registers, SFRs and Bits
#include	"include/80c32x2.h" // Definitions of Philips 80c32x2 registers, SFRs and Bits
#include "include/FlashTestLed_def.h" // defines
#include "include/FlashTestLed_glob.h" // global
#include "include/FlashTestLed_proto.h" // prototypes


// functions ////////////////////////////////////////////////////////////////////////////


void MsDelay(unsigned int iMsDelay)
// stop programm execution for iMsDelay * ms
// the delay is not very accurate, may last longer, depending on interrupts
// funktion calibrated to 8052CPU/11MHz0592/12clockPerCycle
// Parameter:
//		iMsDelay -> delay in milliseconds
{
	unsigned int a,b;

	for (a=iMsDelay; a>0; a--)
	{
		for (b=64; b>0; b--)
		{
			_asm
				nop
			_endasm;
		}
	}
}


void TestLedOn(unsigned char ucState)
// switch TestLed connected to port od CPU on/off
// Parameter:
//		ucState 
//			==0 -> LED off
//			!=0 -> LED on
{
	if (ucState==0)
		TestLed = 0;
	else
		TestLed = 1;
}


void MsgLed(unsigned char ucMsgNr, unsigned char ucLoop)
// show message via flashing LED, amount of flashes identifies message
// Author: Peter Seng (2002)                                         
// Parameter:
//		unsigned char ucMsgNr -> 0x1..0xFF, flash LED ucMsgNr times  
//		unsigned char ucLoop
//			0 -> show message in endless loop (FUNCTION WILL NEVER TERMINATE)
//			0x1..0xFF -> show message ucLoop times   
// Returnvalue : none        
// Last changes: 2002 september 17
{
	unsigned char ucR=0, ucFlash;

	TestLedOn(0); 
	if (ucLoop == 0)
	{
		ucR=1; // endless loop
		ucLoop++;
	}
	while( ucLoop>0 ) // loop
	{
		MsDelay(1500); // 1500ms pause
		for (ucFlash=1; ucFlash<=ucMsgNr; ucFlash++)
		{
			TestLedOn(1); // slow flash TEST LED, show message
			MsDelay(444); // 444ms on
			TestLedOn(0); 
			MsDelay(222); // 222ms off
		}
		if (ucR==1) 
			ucLoop=1; // endless loop
		else
			ucLoop--; // terminated loop
	} // end while
	return;
}


// main /////////////////////////////////////////////////////////////////////////////////
void main( void )
{
	//CKCON = X1; // only for Philips 80c32x2 MCU, initialize clock control register, 12-clock mode (default)
	//CKCON = X2; // only for Philips 80c32x2 MCU, initialize clock control register, 6-clock mode
	MsgLed(3,0); // flash 3 times, endless loop
} // end main

